*****************************************************************************************************
*Date: June 26, 2002
*Project: Beamer and Lewis Steel Duration
*Data: steelduration.dta
*Description: this batch file is intended to read the data into stata, transform it to st data and 
*estimate AFT models of steel mill duration.
*****************************************************************************************************
*First, I need to do some housekeeping.
set memory 128000
set l 72
set level 95
set matsize 150

*Now, I'll look at the spell file.
use steelduration

*Now I will generate a duration variable.
generate age=close-start



generate newcondition=1 if condition==5
replace newcondition=2 if condition==4
replace newcondition=3 if condition==3
replace newcondition=4 if condition==2
replace newcondition=5 if condition==1

*Now I will generate a termination variable
generate terminate=1 if newcondition>1
replace terminate=0 if newcondition==1

stset age terminate

*Now I will describe the survival-time data.

stdes
more

*Now I will summarize the data

stsum
more

*First I graph the product limit estimate of the hazard rate.  

ltable age terminate, hazard graph s(i) c(m) l1(Hazard Rate) t1(Product-Limit Estimates of Hazard Rate)
more

*Now I will estimate full models.  First I will create a log of employment.
generate lnemp=ln(emp)

*I use lnemp to measure shutdown costs.  Durability should increase with lnemp.
*I include emppct to measure the importance of the plant in terms of total firm employement.  The larger
*the percentage of the firm's employees that a mill employees, the higher the durability.
*Similarly, those mills where the managing firm has only one mill, the higher the durability b/c the
*alternative is bankruptcy.
*The geographic variables should increase durability since they represent easy access to markets.
*The tax rate should decrease durability.
*The stlmkr variable should increase durability since it means more efficient mills. Except perhaps for larger firms?
*I should interact this with emppct and maybe indicators for the largest steelmakers.
*I also include fixed effects.
more

oprobit newcondition lnemp emppct single gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv, robust

streg lnemp emppct single gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv, dist(weibull) time
stcox lnemp emppct single gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv
more 

*Now I should try a competing risks model.

stcox lnemp emppct single gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv, strata(newcondition)
stcox lnemp emppct gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv if single==0, strata(newcondition)
more
generate status=1 if newcondition==5
replace status=0 if newcondition<5

stset age status
streg lnemp emppct single gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv, dist(gompertz) 
stcox lnemp emppct single gtlakes coast tax stlmkr armco bethlehem national republic uss wp yst ltv 
more

*Now with only steel producing firms.
clear
use steelmaker

generate newcondition=1 if condition==5
replace newcondition=2 if condition==4
replace newcondition=3 if condition==3
replace newcondition=4 if condition==2
replace newcondition=5 if condition==1

*Now I will generate a termination variable
generate terminate=1 if newcondition>1
replace terminate=0 if newcondition==1

*First I will create a log of employment.
generate lnemp=ln(emp)

stset stduration terminate

*Now I will describe the survival-time data.

stdes
more

*Now I will summarize the data

stsum
more

*First I graph the product limit estimate of the hazard rate.  

ltable stduration terminate, hazard graph s(i) c(m) l1(Hazard Rate) t1(Product-Limit Estimates of Hazard Rate)
more

*I omit ltv b/c it perfectly predicts outcome.

oprobit newcondition lnemp emppct single gtlakes coast tax furnace armco beth national republic uss wp yst
streg lnemp emppct single gtlakes coast tax furnace armco beth national republic uss wp yst, dist (weibull) time
stcox lnemp emppct single gtlakes coast tax furnace armco beth national republic uss wp yst
more

generate status=1 if newcondition==5
replace status=0 if newcondition<5

stset stduration status
streg lnemp emppct single gtlakes coast tax furnace armco beth national republic uss wp yst, dist (weibull) time
stcox lnemp emppct single gtlakes coast tax furnace armco beth national republic uss wp yst
